{stdenv, fetchFromGitHub
, ninja, meson , pkgconfig
, libusb, readline, libewf, perl, zlib, openssl
, gtk2 ? null, vte ? null, gtkdialog ? null
, python ? null
, ruby ? null
, lua ? null
, useX11, rubyBindings, pythonBindings, luaBindings
}:

assert useX11 -> (gtk2 != null && vte != null && gtkdialog != null);
assert rubyBindings -> ruby != null;
assert pythonBindings -> python != null;


let
  inherit (stdenv.lib) optional;
  #<generated>
  # DO NOT EDIT! Automatically generated by ./update.py
  version_commit = "18177";
  gittap = "2.6.0";
  gittip = "83ef480221ec29d82c16003c61d0dc86b8851d38";
  version = "2.6.0";
  sha256 = "18jhb9w8c1m09383d2xm2qp0rc240psjygbbs222hzpx32hald5s";
  cs_tip = "37569a6874c8547b349a80823adda9284499fe80";
  cs_sha256 = "0v31367g4jn4baswl62y0rvvm2nf57y91n3731xqblvi6qxj8qkv";
  #</generated>
in
stdenv.mkDerivation rec {
  name = "radare2-${version}";

  src = fetchFromGitHub {
    owner = "radare";
    repo = "radare2";
    rev = version;
    inherit sha256;
  };

  postPatch = let
    capstone = fetchFromGitHub {
      owner = "aquynh";
      repo = "capstone";
      # version from $sourceRoot/shlr/Makefile
      rev = cs_tip;
      sha256 = cs_sha256;
    };
  in ''
    if ! grep -F "CS_TIP=${cs_tip}" shlr/Makefile; then echo "CS_TIP mismatch"; exit 1; fi
    ln -s ${capstone} shlr/capstone
  '';

  postInstall = ''
    ln -s $out/bin/radare2 $out/bin/r2
    install -D -m755 $src/binr/r2pm/r2pm $out/bin/r2pm
  '';

  mesonFlags = [
    "-Dr2_version_commit=${version_commit}"
    "-Dr2_gittap=${gittap}"
    "-Dr2_gittip=${gittip}"
  ];

  enableParallelBuilding = true;

  nativeBuildInputs = [ pkgconfig ninja meson ];
  buildInputs = [ readline libusb libewf perl zlib openssl]
    ++ optional useX11 [gtkdialog vte gtk2]
    ++ optional rubyBindings [ruby]
    ++ optional pythonBindings [python]
    ++ optional luaBindings [lua];

  meta = {
    description = "unix-like reverse engineering framework and commandline tools";
    homepage = http://radare.org/;
    license = stdenv.lib.licenses.gpl2Plus;
    maintainers = with stdenv.lib.maintainers; [raskin makefu mic92];
    platforms = with stdenv.lib.platforms; linux;
    inherit version;
  };
}
